import os

FILE_PATH = os.path.dirname(__file__)

if 'package-examples' in FILE_PATH:
    PACKAGE_LIB_PATH = os.path.dirname(
        os.path.dirname(
            os.path.dirname(FILE_PATH)
        )
    )
    LIB_PATH = os.path.join(
        PACKAGE_LIB_PATH, "package-libraries", "TI C2000 Toolbox", "lib_path"
    )
else:
    LIB_PATH = os.path.dirname(
        os.path.dirname(FILE_PATH)
    )


BLINKY = 'test_blinky.py'
DAB = 'test_closed_loop_dab.py'
PMSM = 'test_foc_pmsm.py'
INVERTER_3LVL = 'test_open_loop_3_lvl_inverter.py'
BUCK = 'test_open_loop_buck.py'
LLC = 'test_open_loop_llc_converter.py'
SIN_PWM = 'test_sinusoidal_pwm.py'

INTERFACE_LAUNCHPAD = "HIL TI Launchpad Interface"
INTERFACE_UGRID = "HIL TI uGrid Launchpad Interface"
INTERFACE_180 = "HIL DSP 180 Interface"
INTERFACE_100 = "HIL DSP Interface"

DEVICE_3V0 = [
    "LAUNCHXL-F28379D", "TMDSCNCD28379D"
]
DEVICE_3V3 = [
    "LAUNCHXL-F280049C", "LAUNCHXL-F280039C", "LAUNCHXL-F280025C", "LAUNCHXL-F2800137"
]
DEVICE_5V0 = [
    "TMDSCNCD28335"
]

INTERFACE_PARAMS = {
    INTERFACE_LAUNCHPAD: {
        "scaling": 1.5,
        "offset": 1.5,
        "limits": (0, 3)
    },
    INTERFACE_UGRID: {
        "scaling": 1.5,
        "offset": 1.5,
        "limits": (0, 3)
    },
    INTERFACE_180: {
        "scaling": 1.5,
        "offset": 1.5,
        "limits": (0, 3)
    },
    INTERFACE_100: {
        "scaling": 5,
        "offset": 0,
        "limits": (-5, 5)
    }
}

EPWM_B_CHANNEL_OFFSET = {
    INTERFACE_LAUNCHPAD: 1,
    INTERFACE_UGRID: 1,
    INTERFACE_180: 6,
    INTERFACE_100: 6,
}

LAUNCHPAD_DEVICES = [
    "F28379D",
    "F280049C",
    "F280039C",
    "F280025C",
    "F2800137"
]

CONTROL_CARD_DEVICES = [
    "F28379D",
    "F28335",
    "F2808"
]

CONTROL_CARD_180_DEVICES = [
    "F28379D"
]

CONTROL_CARD_100_DEVICES = [
    "F28335",
    "F2808"
]

ALL_DEVICES = LAUNCHPAD_DEVICES + CONTROL_CARD_DEVICES + CONTROL_CARD_180_DEVICES + CONTROL_CARD_100_DEVICES
ALL_INTERFACES = [
    INTERFACE_LAUNCHPAD, INTERFACE_UGRID, INTERFACE_180, INTERFACE_100
]

INTERFACE_SUPPORT = {
    INTERFACE_LAUNCHPAD: LAUNCHPAD_DEVICES,
    INTERFACE_UGRID: LAUNCHPAD_DEVICES,
    INTERFACE_180: CONTROL_CARD_180_DEVICES,
    INTERFACE_100: CONTROL_CARD_100_DEVICES
}

# Temp
TEST_SUPPORT_DEVICE = {
    BLINKY: ALL_DEVICES,
    DAB: ALL_DEVICES,
    PMSM: ALL_DEVICES,
    INVERTER_3LVL: ["F28379D", "F28335", "F280049C", "F280039C"],
    BUCK: ALL_DEVICES,
    LLC: ALL_DEVICES,
    SIN_PWM: ALL_DEVICES,
}

TEST_SUPPORT_INTERFACE = {
    BLINKY: ALL_INTERFACES,
    DAB: ALL_INTERFACES,
    PMSM: [INTERFACE_LAUNCHPAD, INTERFACE_180, INTERFACE_100],
    INVERTER_3LVL: ALL_INTERFACES,
    BUCK: ALL_INTERFACES,
    LLC: ALL_INTERFACES,
    SIN_PWM: ALL_INTERFACES,
}

HW_REQUIREMENTS = {
    BLINKY: None,
    DAB: ["hw_dc_dc_conv_solver"],
    PMSM: ["hw_machine_solver", "sw_nonlinear_machines"],
    INVERTER_3LVL: None,
    BUCK: None,
    LLC: ["hw_dc_dc_conv_solver"],
    SIN_PWM: None,
}